.. _linear_algebra:

Linear Algebra
--------------

The next functions can be used for computing linear algebra operations with :ref:`NDArray <NDArray>`.

.. currentmodule:: blosc2

.. autosummary::
   :toctree: autofiles/operations_with_arrays/
   :nosignatures:

    matmul
    transpose
    matrix_transpose
    permute_dims
